@@ -2,20 +2,9 @@
 
 import time
 import requests
-from json import dumps
-from typing import Any, Dict, List, Optional, Union
+from typing import Optional
 
 
-def jsonPrint(
-    content: Optional[Union[Dict[str, Any], List[Any]]] = {},
-    title: Optional[str] = None,
-) -> None:
-    if title is not None:
-        data = {title: content}
-    else:
-        data = content
-    print(dumps(data, indent=2))
-
 class Fetch:
     def __init__(self, url: str):
         self.base_url = url
@@ -30,4 +19,15 @@ class Fetch:
                 response = requests.get(url, timeout=4)
                 time.sleep(1)
         print(" [OK]")
-        return response.text or None
\ No newline at end of file
+        return response.text or None
+
+
+def wait_result(func, *args, **kargs):
+    while True:
+        try:
+            result = func(*args, **kargs)
+            return result
+        except:
+            print("\rWaiting for result...", end="")
+            time.sleep(0.1)
+            continue
